==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/PdfaType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PdfaType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PdfaType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;element name="convert"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;all&gt;
 *                   &lt;element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/&gt;
 *                 &lt;/all&gt;
 *                 &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
 *                 &lt;attribute name="imageQuality" default="75"&gt;
 *                   &lt;simpleType&gt;
 *                     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *                       &lt;minInclusive value="0"/&gt;
 *                       &lt;maxInclusive value="100"/&gt;
 *                     &lt;/restriction&gt;
 *                   &lt;/simpleType&gt;
 *                 &lt;/attribute&gt;
 *                 &lt;attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" /&gt;
 *                 &lt;attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" /&gt;
 *                 &lt;attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="analyze"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/choice&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PdfaType", propOrder = {
    "convert",
    "analyze"
})
public class PdfaType {

    protected PdfaType.Convert convert;
    protected PdfaType.Analyze analyze;

    /**
     * Gets the value of the convert property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Convert }
     *     
     */
    public PdfaType.Convert getConvert() {
        return convert;
    }

    /**
     * Sets the value of the convert property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Convert }
     *     
     */
    public void setConvert(PdfaType.Convert value) {
        this.convert = value;
    }

    public boolean isSetConvert() {
        return (this.convert!= null);
    }

    /**
     * Gets the value of the analyze property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public PdfaType.Analyze getAnalyze() {
        return analyze;
    }

    /**
     * Sets the value of the analyze property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public void setAnalyze(PdfaType.Analyze value) {
        this.analyze = value;
    }

    public boolean isSetAnalyze() {
        return (this.analyze!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Analyze {

        @XmlAttribute(name = "level")
        protected String level;

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLevel() {
            if (level == null) {
                return "3b";
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLevel(String value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;all&gt;
     *         &lt;element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/&gt;
     *       &lt;/all&gt;
     *       &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
     *       &lt;attribute name="imageQuality" default="75"&gt;
     *         &lt;simpleType&gt;
     *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
     *             &lt;minInclusive value="0"/&gt;
     *             &lt;maxInclusive value="100"/&gt;
     *           &lt;/restriction&gt;
     *         &lt;/simpleType&gt;
     *       &lt;/attribute&gt;
     *       &lt;attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" /&gt;
     *       &lt;attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" /&gt;
     *       &lt;attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {

    })
    public static class Convert {

        protected ZugferdType zugferd;
        @XmlAttribute(name = "level")
        protected String level;
        @XmlAttribute(name = "imageQuality")
        protected Integer imageQuality;
        @XmlAttribute(name = "errorReport")
        protected PdfaErrorReportType errorReport;
        @XmlAttribute(name = "successReport")
        protected PdfaSuccessReportType successReport;
        @XmlAttribute(name = "autoTagging")
        protected Boolean autoTagging;

        /**
         * Gets the value of the zugferd property.
         * 
         * @return
         *     possible object is
         *     {@link ZugferdType }
         *     
         */
        public ZugferdType getZugferd() {
            return zugferd;
        }

        /**
         * Sets the value of the zugferd property.
         * 
         * @param value
         *     allowed object is
         *     {@link ZugferdType }
         *     
         */
        public void setZugferd(ZugferdType value) {
            this.zugferd = value;
        }

        public boolean isSetZugferd() {
            return (this.zugferd!= null);
        }

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLevel() {
            if (level == null) {
                return "3b";
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLevel(String value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

        /**
         * Gets the value of the imageQuality property.
         * 
         * @return
         *     possible object is
         *     {@link Integer }
         *     
         */
        public int getImageQuality() {
            if (imageQuality == null) {
                return  75;
            } else {
                return imageQuality;
            }
        }

        /**
         * Sets the value of the imageQuality property.
         * 
         * @param value
         *     allowed object is
         *     {@link Integer }
         *     
         */
        public void setImageQuality(int value) {
            this.imageQuality = value;
        }

        public boolean isSetImageQuality() {
            return (this.imageQuality!= null);
        }

        public void unsetImageQuality() {
            this.imageQuality = null;
        }

        /**
         * Gets the value of the errorReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public PdfaErrorReportType getErrorReport() {
            if (errorReport == null) {
                return PdfaErrorReportType.NONE;
            } else {
                return errorReport;
            }
        }

        /**
         * Sets the value of the errorReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public void setErrorReport(PdfaErrorReportType value) {
            this.errorReport = value;
        }

        public boolean isSetErrorReport() {
            return (this.errorReport!= null);
        }

        /**
         * Gets the value of the successReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public PdfaSuccessReportType getSuccessReport() {
            if (successReport == null) {
                return PdfaSuccessReportType.NONE;
            } else {
                return successReport;
            }
        }

        /**
         * Sets the value of the successReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public void setSuccessReport(PdfaSuccessReportType value) {
            this.successReport = value;
        }

        public boolean isSetSuccessReport() {
            return (this.successReport!= null);
        }

        /**
         * Gets the value of the autoTagging property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isAutoTagging() {
            if (autoTagging == null) {
                return false;
            } else {
                return autoTagging;
            }
        }

        /**
         * Sets the value of the autoTagging property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setAutoTagging(boolean value) {
            this.autoTagging = value;
        }

        public boolean isSetAutoTagging() {
            return (this.autoTagging!= null);
        }

        public void unsetAutoTagging() {
            this.autoTagging = null;
        }

    }

}

==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/operation/PdfaType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import net.webpdf.wsclient.ParameterInterface;


/**
 * 
 * 
 * <p>Java class for PdfaType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PdfaType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;element name="convert"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;all&gt;
 *                   &lt;element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/&gt;
 *                 &lt;/all&gt;
 *                 &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
 *                 &lt;attribute name="imageQuality" default="75"&gt;
 *                   &lt;simpleType&gt;
 *                     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *                       &lt;minInclusive value="0"/&gt;
 *                       &lt;maxInclusive value="100"/&gt;
 *                     &lt;/restriction&gt;
 *                   &lt;/simpleType&gt;
 *                 &lt;/attribute&gt;
 *                 &lt;attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" /&gt;
 *                 &lt;attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" /&gt;
 *                 &lt;attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="analyze"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/choice&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PdfaType", propOrder = {
    "convert",
    "analyze"
})
public class PdfaType
    implements ParameterInterface
{

    protected PdfaType.Convert convert;
    protected PdfaType.Analyze analyze;

    /**
     * Gets the value of the convert property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Convert }
     *     
     */
    public PdfaType.Convert getConvert() {
        return convert;
    }

    /**
     * Sets the value of the convert property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Convert }
     *     
     */
    public void setConvert(PdfaType.Convert value) {
        this.convert = value;
    }

    public boolean isSetConvert() {
        return (this.convert!= null);
    }

    /**
     * Gets the value of the analyze property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public PdfaType.Analyze getAnalyze() {
        return analyze;
    }

    /**
     * Sets the value of the analyze property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public void setAnalyze(PdfaType.Analyze value) {
        this.analyze = value;
    }

    public boolean isSetAnalyze() {
        return (this.analyze!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Analyze {

        @XmlAttribute(name = "level")
        protected PdfaLevelType level;

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaLevelType }
         *     
         */
        public PdfaLevelType getLevel() {
            if (level == null) {
                return PdfaLevelType.LEVEL_3B;
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaLevelType }
         *     
         */
        public void setLevel(PdfaLevelType value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;all&gt;
     *         &lt;element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/&gt;
     *       &lt;/all&gt;
     *       &lt;attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" /&gt;
     *       &lt;attribute name="imageQuality" default="75"&gt;
     *         &lt;simpleType&gt;
     *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
     *             &lt;minInclusive value="0"/&gt;
     *             &lt;maxInclusive value="100"/&gt;
     *           &lt;/restriction&gt;
     *         &lt;/simpleType&gt;
     *       &lt;/attribute&gt;
     *       &lt;attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" /&gt;
     *       &lt;attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" /&gt;
     *       &lt;attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {

    })
    public static class Convert {

        protected ZugferdType zugferd;
        @XmlAttribute(name = "level")
        protected PdfaLevelType level;
        @XmlAttribute(name = "imageQuality")
        protected Integer imageQuality;
        @XmlAttribute(name = "errorReport")
        protected PdfaErrorReportType errorReport;
        @XmlAttribute(name = "successReport")
        protected PdfaSuccessReportType successReport;
        @XmlAttribute(name = "autoTagging")
        protected Boolean autoTagging;

        /**
         * Gets the value of the zugferd property.
         * 
         * @return
         *     possible object is
         *     {@link ZugferdType }
         *     
         */
        public ZugferdType getZugferd() {
            return zugferd;
        }

        /**
         * Sets the value of the zugferd property.
         * 
         * @param value
         *     allowed object is
         *     {@link ZugferdType }
         *     
         */
        public void setZugferd(ZugferdType value) {
            this.zugferd = value;
        }

        public boolean isSetZugferd() {
            return (this.zugferd!= null);
        }

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaLevelType }
         *     
         */
        public PdfaLevelType getLevel() {
            if (level == null) {
                return PdfaLevelType.LEVEL_3B;
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaLevelType }
         *     
         */
        public void setLevel(PdfaLevelType value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

        /**
         * Gets the value of the imageQuality property.
         * 
         * @return
         *     possible object is
         *     {@link Integer }
         *     
         */
        public int getImageQuality() {
            if (imageQuality == null) {
                return  75;
            } else {
                return imageQuality;
            }
        }

        /**
         * Sets the value of the imageQuality property.
         * 
         * @param value
         *     allowed object is
         *     {@link Integer }
         *     
         */
        public void setImageQuality(int value) {
            this.imageQuality = value;
        }

        public boolean isSetImageQuality() {
            return (this.imageQuality!= null);
        }

        public void unsetImageQuality() {
            this.imageQuality = null;
        }

        /**
         * Gets the value of the errorReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public PdfaErrorReportType getErrorReport() {
            if (errorReport == null) {
                return PdfaErrorReportType.NONE;
            } else {
                return errorReport;
            }
        }

        /**
         * Sets the value of the errorReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public void setErrorReport(PdfaErrorReportType value) {
            this.errorReport = value;
        }

        public boolean isSetErrorReport() {
            return (this.errorReport!= null);
        }

        /**
         * Gets the value of the successReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public PdfaSuccessReportType getSuccessReport() {
            if (successReport == null) {
                return PdfaSuccessReportType.NONE;
            } else {
                return successReport;
            }
        }

        /**
         * Sets the value of the successReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public void setSuccessReport(PdfaSuccessReportType value) {
            this.successReport = value;
        }

        public boolean isSetSuccessReport() {
            return (this.successReport!= null);
        }

        /**
         * Gets the value of the autoTagging property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isAutoTagging() {
            if (autoTagging == null) {
                return false;
            } else {
                return autoTagging;
            }
        }

        /**
         * Sets the value of the autoTagging property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setAutoTagging(boolean value) {
            this.autoTagging = value;
        }

        public boolean isSetAutoTagging() {
            return (this.autoTagging!= null);
        }

        public void unsetAutoTagging() {
            this.autoTagging = null;
        }

    }

}
